PapercupsProps class

This contains all the possible configurations for the chat widget.

Constructors

PapercupsProps({required String accountId, String baseUrl = 'app.papercups.io', PapercupsCustomerMetadata? customer, Widget closeIcon = const Icon(Icons.close_rounded), VoidCallback? closeAction, bool scrollEnabled = true, bool floatingSendMessage = false, bool requireEmailUpfront = false, Widget? sendIcon, void onMessageBubbleTap(PapercupsMessage)?, PapercupsStyle style = const PapercupsStyle(), PapercupsIntl translations = const PapercupsIntl()})
const

Properties

accountId → String
Required to create the widget, identifies the account.
final
baseUrl → String
If you are self-hosting papercups, this base URL should be changed.
final
closeAction → VoidCallback?
Function to handle closing the widget. If not null, close button will be shown.
final
closeIcon → Widget
This is the close button displayed in the header section.
final
customer → PapercupsCustomerMetadata?
This is the data that you will see on your dashboard such as the email or the name of the user.
final
floatingSendMessage → bool
Set to true in order to make the send message section float
final
hashCode → int
The hash code for this object.
no setterinherited
onMessageBubbleTap → void Function(PapercupsMessage)?
Function to handle message bubble tap action.
final
requireEmailUpfront → bool
If you want to require unidentified customers to provide their email before they can message you. Not recommended for apps.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollEnabled → bool
This allows you to choose if you want to show your status. Whether or not to allow scrolling.
final
sendIcon → Widget?
Message send icon in the chat text field
final
style → PapercupsStyle
This class contains all the styling options used by the widget.
final
translations → PapercupsIntl
This contains all the texts that can be displayed by the widget.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited