PapercupsStyle class

This class contains all the styling options used by the widget.

Constructors

PapercupsStyle({Color? primaryColor = const Color(0xFF1890FF), Gradient? primaryGradient, Color? backgroundColor, TextStyle? titleStyle, TextAlign? titleAlign = TextAlign.left, TextStyle? subtitleStyle, double? headerHeight, EdgeInsetsGeometry headerPadding = const EdgeInsets.only(top: 16, right: 20, left: 20, bottom: 12), Widget? noConnectionIcon, TextStyle? noConnectionTextStyle, InputDecoration? requireEmailUpfrontInputDecoration, Brightness? requireEmailUpfrontKeyboardAppearance = Brightness.light, TextStyle? requireEmailUpfrontInputHintStyle = const TextStyle(fontSize: 14), TextStyle? requireEmailUpfrontInputTextStyle, BoxDecoration? floatingSendMessageBoxDecoration, BoxDecoration? sendMessageBoxDecoration, Brightness? sendMessageKeyboardAppearance = Brightness.light, InputDecoration? sendMessagePlaceholderInputDecoration, TextStyle? sendMessagePlaceholderTextStyle = const TextStyle(fontSize: 14), TextStyle? sendMessageInputTextStyle, BoxDecoration? botBubbleBoxDecoration, TextStyle? botBubbleTextStyle, BoxDecoration? userBubbleBoxDecoration, BoxDecoration? botAttachmentBoxDecoration, TextStyle? botAttachmentTextStyle, TextStyle? botBubbleUsernameTextStyle, TextStyle? userBubbleTextStyle, BoxDecoration? userAttachmentBoxDecoration, TextStyle? userAttachmentTextStyle, TextStyle? userBubbleSentAtTextStyle, TextStyle? chatBubbleTimeTextStyle, TextStyle? chatBubbleFullDateTextStyle, TextStyle? chatUploadingAlertTextStyle, Color? chatUploadingAlertBackgroundColor, TextStyle? chatUploadErrorAlertTextStyle, Color? chatUploadErrorAlertBackgroundColor, TextStyle? chatNoConnectionAlertTextStyle, Color? chatNoConnectionAlertBackgroundColor, TextStyle? chatCopiedTextAlertTextStyle, Color? chatCopiedTextAlertBackgroundColor})
const

Properties

backgroundColor → Color?
Color used in the background of the entire widget.
final
botAttachmentBoxDecoration → BoxDecoration?
Box decoration of the bot attachment (images, files) chat bubbles.
final
botAttachmentTextStyle → TextStyle?
Text style of the bot attachments file name.
final
botBubbleBoxDecoration → BoxDecoration?
Box decoration of the bot chat bubbles.
final
botBubbleTextStyle → TextStyle?
Text style of the bot chat bubbles.
final
botBubbleUsernameTextStyle → TextStyle?
Text style of bot user name displayed below its chat bubbles.
final
chatBubbleFullDateTextStyle → TextStyle?
Text style of the date displayed centered in the chat before the chat bubbles of a given day.
final
chatBubbleTimeTextStyle → TextStyle?
Text style of the time stamp displayed (on tap) next to the any chat bubble.
final
chatCopiedTextAlertBackgroundColor → Color?
Background color of the alert shown when a chat bubble gets long pressed and its text copied.
final
chatCopiedTextAlertTextStyle → TextStyle?
Text style of the alert shown when a chat bubble gets long pressed and its text copied.
final
chatNoConnectionAlertBackgroundColor → Color?
Background color of the alert shown when the chat is displayed but no Internet connection is available.
final
chatNoConnectionAlertTextStyle → TextStyle?
Text style of the alert shown when the chat is displayed but no Internet connection is available.
final
chatUploadErrorAlertBackgroundColor → Color?
Background color of the error alert shown when an attachment failed to upload.
final
chatUploadErrorAlertTextStyle → TextStyle?
Text style of the error alert shown when an attachment failed to upload.
final
chatUploadingAlertBackgroundColor → Color?
Background color of the alert shown when an attachment is being uploaded.
final
chatUploadingAlertTextStyle → TextStyle?
Text style of the alert shown when an attachment is being uploaded.
final
floatingSendMessageBoxDecoration → BoxDecoration?
Box decoration of the message text field when floatingSendMessage prop is true.
final
hashCode → int
The hash code for this object.
no setterinherited
headerHeight → double?
Widget header height.
final
headerPadding → EdgeInsetsGeometry
Widget header padding.
final
noConnectionIcon → Widget?
Widget displayed in the widget when there's no Internet connection.
final
noConnectionTextStyle → TextStyle?
Text style of the text displayed in the widget when there's no Internet connection.
final
primaryColor → Color?
Color in which the header is going to be in, if not defined will be primary color used in app.
final
primaryGradient → Gradient?
Gradient to specify, should be used instead of primaryColor, DO NOT USE BOTH.
final
requireEmailUpfrontInputDecoration → InputDecoration?
Input decoration of the require email text field.
final
requireEmailUpfrontInputHintStyle → TextStyle?
Text style of the require email text field hint.
final
requireEmailUpfrontInputTextStyle → TextStyle?
Text style of the require email text field.
final
requireEmailUpfrontKeyboardAppearance → Brightness?
Keyboard brightness of the require email text field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendMessageBoxDecoration → BoxDecoration?
Box decoration of the message text field.
final
sendMessageInputTextStyle → TextStyle?
Text style of the message text field input.
final
sendMessageKeyboardAppearance → Brightness?
Keyboard brightness of the send message text field.
final
sendMessagePlaceholderInputDecoration → InputDecoration?
Input decoration of the message text field.
final
sendMessagePlaceholderTextStyle → TextStyle?
Text style of the message text field input hint text.
final
subtitleStyle → TextStyle?
This is the widget sub title text style.
final
titleAlign → TextAlign?
This is the top widget title alignment.
final
titleStyle → TextStyle?
Text style of the title at the top of the chat widget.
final
userAttachmentBoxDecoration → BoxDecoration?
Box decoration of the user attachment (images, files) chat bubbles.
final
userAttachmentTextStyle → TextStyle?
Text style of the user attachments file name.
final
userBubbleBoxDecoration → BoxDecoration?
Box decoration of the user chat bubbles.
final
userBubbleSentAtTextStyle → TextStyle?
Text style of the "Sent x ago" (or "Sending...") text displayed below the latest user chat bubble.
final
userBubbleTextStyle → TextStyle?
Text style of the user chat bubbles.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited