User class

This class is used for the agent sending the messages.

Constructors

User({DateTime? createdAt, DateTime? disabledAt, String? email, int? id, String? role, String? displayName, String? profilePhotoUrl})

Properties

createdAt ↔ DateTime?
The time the agent was created.
getter/setter pair
disabledAt ↔ DateTime?
The time the agent was disabled. If null, agent is enabled.
getter/setter pair
displayName ↔ String?
The display name of the agent. May be null.
getter/setter pair
email ↔ String?
The email of the agent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The unique ID of the person in Papercups.
getter/setter pair
profilePhotoUrl ↔ String?
The profile photo of the agent, must be a valid URL or null.
getter/setter pair
role ↔ String?
The role of the agent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited